AndroidUpgradeOption class

Android Upgrade Option.

如果手机厂商为OPPO,parameters 支持拼接参数 https://open.oppomobile.com/new/developmentDoc/info?id=11869

如果手机厂商为vivo,parameters 支持拼接参数 https://swsdl.vivo.com.cn/appstore/developer/uploadFile/20241224/vxpbua/vivo%E5%BC%80%E6%94%BE%E5%B9%B3%E5%8F%B0%E5%95%86%E5%BA%97%E8%87%AA%E6%9B%B4%E6%96%B02.0.pdf

如果手机厂商为小米,因小米已关闭直投1.0模式,故建议采用统一链接服务(OneLink)或者直投2.0模式 如果使用直投2.0,请确保已开通直投2.0服务,否则无法正常跳转,并将额外参数通过parameters传入。 统一链接服务(OneLink)操作指南: https://dev.mi.com/xiaomihyperos/documentation/detail?pId=1965 直投2.0: https://dev.mi.com/xiaomihyperos/documentation/detail?pId=1350

统一链接服务(OneLink)目前支持华为、小米、OPPO、vivo、Apple以及PC https://www.malink.cn/

Constructors

AndroidUpgradeOption({required AndroidBrand brand, String? packageName, String? link, String? downloadUrl, Map<String, dynamic>? parameters})

Properties

brand → AndroidBrand
The brand of the current device.
final
channel ↔ MethodChannel?
getter/setter pair
downloadUrl → String?
Download url.
final
hashCode → int
The hash code for this object.
no setterinherited
Custom link. Used for AndroidBrand.xiaomi or AndroidBrand.custom.
final
packageName → String?
The name of package.
final
parameters → Map<String, dynamic>?
Custom parameters; stitched after url.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → Future<String>
Link.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited